@@ -7,7 +7,6 @@
  *  Arnaud Martin, Antoine Pitrou, Philippe Rivière, Emmanuel Saint-James  *
  *                                                                         *
  *  Ce programme est un logiciel libre distribué sous licence GNU/GPL.     *
- *  Pour plus de détails voir le fichier COPYING.txt ou l'aide en ligne.   *
 \***************************************************************************/
 
 /**
@@ -44,7 +43,7 @@ include_spip('inc/texte');
  * @param string $descriptif
  *     Descriptif de l'introduction
  * @param string $texte
- *     Texte à utiliser en absence de descriptif
+ *     texte à utiliser en absence de descriptif
  * @param string $longueur
  *     Longueur de l'introduction
  * @param string $connect
@@ -350,7 +349,7 @@ function retrouver_rang_lien($objet_source, $ids, $objet_lie, $idl, $objet_lien)
 
 /**
  * Lister les liens en le memoizant dans une static
- * pour utilisation commune par lister_objets_lies et retrouver_rang_lien dans un formuluaire d'edition de liens
+ * pour utilisation commune par lister_objets_lies et retrouver_rang_lien dans un formulaire d'edition de liens
  * (evite de multiplier les requetes)
  *
  * @param $objet_source
@@ -407,6 +406,106 @@ function calculer_rang_smart($titre, $objet_source, $id, $env) {
 	return recuperer_numero($titre);
 }
 
+/**
+ * Calcul de la balise #TRI
+ *
+ * @param string $champ_ou_sens
+ *     - soit le nom de champ sur lequel effectuer le nouveau tri
+ *     - soit `<` et `>` pour définir le sens du tri sur le champ actuel
+ * @param string $libelle
+ *     Texte du lien
+ * @param string $classe
+ *     Classe ajoutée au lien, telle que `ajax`
+ * @param string           $tri_nom
+ *     Nom du paramètre définissant le tri
+ * @param string           $tri_champ
+ *     Nom du champ actuel utilisé pour le tri
+ * @param string           $tri_sens
+ *     Sens de tri actuel, 1 ou -1
+ * @param array|string|int $liste_tri_sens_defaut
+ *     Soit la liste des sens de tri par défaut pour chaque champ
+ *     Soit une valeur par défaut pour tous les champs (1, -1, inverse)
+ * @param string           $nom_pagination
+ *     Nom de la boucle
+ * @return string
+ *     HTML avec un lien cliquable
+ */
+function calculer_balise_tri(string $champ_ou_sens, string $libelle, string $classe, string $tri_nom, string $tri_champ, string $tri_sens, $liste_tri_sens_defaut, string $nom_pagination = ''): string {
+
+	$url = self('&');
+	$tri_sens = (int) $tri_sens;
+	$alias_sens = [
+		'<' => -1,
+		'>' => 1,
+		'inverse' => -1,
+	];
+
+	// Normaliser la liste des sens de tri par défaut
+	// On ajoute un jocker pour les champs non présents dans la liste
+	// avec la valeur du 1er item de la liste, idem critère {tri}
+	if (is_array($liste_tri_sens_defaut)) {
+		$liste_tri_sens_defaut['*'] = array_values($liste_tri_sens_defaut)[0];
+	} else {
+		$liste_tri_sens_defaut = [
+			'*' => (int) ($alias_sens[$liste_tri_sens_defaut] ?? $liste_tri_sens_defaut),
+		];
+	}
+
+	// Les sens de tri actuel et nouveau :
+	// Soit c'est un sens fixe donné en paramètre (< ou >)
+	$is_sens_fixe = array_key_exists($champ_ou_sens, $alias_sens);
+	if ($is_sens_fixe) {
+		$tri_sens_actuel = $tri_sens;
+		$tri_sens_nouveau = $alias_sens[$champ_ou_sens];
+	// Soit c'est le champ utilisé actuellement pour le tri → on inverse le sens
+	} elseif ($champ_ou_sens === $tri_champ) {
+		$tri_sens_actuel = $tri_sens;
+		$tri_sens_nouveau = $tri_sens * -1;
+	// Sinon c'est un nouveau champ, et on prend son tri par défaut
+	} else {
+		$tri_sens_actuel = $tri_sens_nouveau = (int) ($liste_tri_sens_defaut[$champ_ou_sens] ?? $liste_tri_sens_defaut['*']);
+	}
+
+	// URL : ajouter le champ sur lequel porte le tri
+	if (!$is_sens_fixe) {
+		$param_tri = "tri$tri_nom";
+		$url = parametre_url($url, $param_tri, $champ_ou_sens);
+	}
+
+	// URL : n'ajouter le sens de tri que si nécessaire,
+	// c.à.d différent du sens par défaut pour le champ
+	$param_sens = "sens$tri_nom";
+	$tri_sens_defaut_champ = (int) ($liste_tri_sens_defaut[$champ_ou_sens] ?? $liste_tri_sens_defaut['*']);
+	if ($tri_sens_nouveau !== $tri_sens_defaut_champ) {
+		$url = parametre_url($url, $param_sens, $tri_sens_nouveau);
+	} else {
+		$url = parametre_url($url, $param_sens, '');
+	}
+
+	// Drapeau pour garder en session ?
+	$param_memo = (!$is_sens_fixe ? $param_tri : $param_sens);
+	$url = parametre_url($url, 'var_memotri', strncmp($tri_nom, 'session', 7) == 0 ? $param_memo : '');
+
+	// Classes : on indique le sens de tri et l'item exposé
+	if (!$is_sens_fixe) {
+		$classe .= ' item-tri item-tri_' . ($tri_sens_actuel === 1 ? 'asc' : 'desc');
+	}
+	if ($champ_ou_sens === $tri_champ) {
+		$classe .= ' item-tri_actif';
+	}
+
+	// Si on n'est pas en mode "Tout afficher" de la pagination
+	if ($nom_pagination && parametre_url($url, 'debut' . $nom_pagination) !== '-1') {
+		// reset la pagination quand on change de mode ou de sens de tri
+		$url = parametre_url($url, 'debut' . $nom_pagination, '');
+	}
+
+	// Lien
+	$balise = lien_ou_expose($url, $libelle, false, $classe);
+
+	return $balise;
+}
+
 
 /**
  * Proteger les champs passes dans l'url et utiliser dans {tri ...}
@@ -526,7 +625,7 @@ function formate_liste_critere_par_ordre_liste($valeurs, $serveur = '') {
  * @uses chercher_filtre()
  *
  * @param mixed $arg
- *     Texte (le plus souvent) sur lequel appliquer le filtre
+ *     texte (le plus souvent) sur lequel appliquer le filtre
  * @param string $filtre
  *     Nom du filtre à appliquer
  * @param array $args
@@ -534,7 +633,7 @@ function formate_liste_critere_par_ordre_liste($valeurs, $serveur = '') {
  * @param mixed $defaut
  *     Valeur par défaut à retourner en cas d'absence du filtre.
  * @return string
- *     Texte traité par le filtre si le filtre existe,
+ *     texte traité par le filtre si le filtre existe,
  *     Valeur $defaut sinon.
  **/
 function appliquer_filtre_sinon($arg, $filtre, $args, $defaut = '') {
@@ -555,3 +654,38 @@ function appliquer_filtre_sinon($arg, $filtre, $args, $defaut = '') {
 	array_shift($args); // enlever $filtre
 	return $f($arg, ...$args);
 }
+
+/**
+ * generer le style dynamique inline pour la page de login et spip_pass
+ * @param array $Pile Pile de données
+ * @param ...$dummy
+ * @return string
+ */
+function filtre_styles_inline_page_login_pass_dist(&$Pile,...$dummy) {
+	$styles = '';
+	include_spip('inc/config');
+	if ($couleur = lire_config('couleur_login')) {
+		include_spip('inc/filtres_images_mini');
+		$hs = couleur_hex_to_hsl($couleur, 'h, s');
+		$l = couleur_hex_to_hsl($couleur, 'l');
+		$styles .= ":root {--spip-login-color-theme--hs: {$hs};--spip-login-color-theme--l: {$l};}\n";
+	}
+	$logo_bg = _DIR_IMG . "spip_fond_login.jpg";
+	if (file_exists($logo_bg)) {
+		include_spip('inc/filtres_images_mini');
+		$logo_mini = image_reduire($logo_bg, 64, 64);
+		$logo_mini = extraire_attribut($logo_mini, 'src');
+		$embarque_fichier = charger_filtre('embarque_fichier');
+		$logo_mini = $embarque_fichier($logo_mini);
+		$logo_bg = timestamp($logo_bg);
+		$styles .= ".page_login, .page_spip_pass {background-image:url($logo_bg), url($logo_mini);}\n";
+		$Pile[0]['body_class'] = 'fond_image';
+	}
+	else {
+		$Pile[0]['body_class'] = 'sans_fond';
+	}
+	if ($styles) {
+		$styles = "<style type='text/css'>$styles</style>";
+	}
+	return $styles;
+}
